#
# spec file for package python-ipy
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-ipy
Version:        1.01
Release:        1.14
Summary:        Class and tools for handling of IPv4 and IPv6 addresses and networks
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/autocracy/python-ipy
Source:         https://files.pythonhosted.org/packages/source/I/IPy/IPy-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch

%python_subpackages

%description
The IP class allows a comfortable parsing and handling for most
notations in use for IPv4 and IPv6 addresses and networks. It was
greatly inspired by RIPE's Perl module NET::IP's interface but
doesn't share the implementation. It doesn't share non-CIDR netmasks,
so funky stuff like a netmask of 0xffffff0f can't be done here.

%prep
%setup -q -n IPy-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%files %{python_files}
%{python_sitelib}/*
%license COPYING

%check
%python_exec test/test_IPy.py
# one of 3000 subtest fails, probably https://github.com/autocracy/python-ipy/issues/27
# %%python_exec test/test_fuzz.py

%changelog
* Thu Jan 28 2021 Dirk Müller <dmueller@suse.com>
- update to 1.01:
  * Update to support up to Python 3.9
* Tue May 21 2019 pgajdos@suse.com
- version update to 1.00
  * Fix IPv6 string interpretation for small ints
  * Various Python3 language fixes
  * consider 127.0 range LOOPBACK not PRIVATE
* Thu Nov 22 2018 jsegitz@suse.com
- Update to version 0.83
  * Add carrier grade NAT ranges
  * Unbreak lots of packing systems by not having a letter in the release version
  * Correct x.next() -> next(x) python3 compatability
  * Add support for array slices
  * Add __and__ and isdisjoint for IPSet
  * Fix a bug in IPSet where contains may incorrectly return false
- Moved to singlespec and added explicit license
* Sun Dec  8 2013 p.drouand@gmail.com
- Update to version 0.81
  * Correct reverseName() for IPv6 addresses, so IP('::1').reverseName()
    returns correct.
  * Add network mask awareness to v46map()
  * Fix Python 3 errors in IPSet class
  * Make IPSet base class be object when MutableSet isn't available, fixing
    errors in Python 2.5
- Changes from 0.80
  * Drop support of Python older than 2.4
  * Python 3 does not need 2to3 conversion anymore (same code base)
  * Fix adding of non-adjacent networks:
    192.168.0.0/24 + 192.168.255.0/24 made 192.168.0.0/23
  * Fix adding networks that don't create a valid subnet:
    192.168.1.0/24 + 192.168.2.0/24 made 192.168.1.0/23
  * Fix adding with an IPv6 address where .int() was < 32 bits made
    IPy believe it was an IPv4 address:
  ::ffff:0/112 + ::1:0:0/112 made 255.255.0.0/111
  * Add support of IPSets
  * Add support for subtracting a network range
  * Prevent IPv4 and IPv6 ranges from saying they contain each other
  * Add a .v46map() method to convert mapped address ranges
    such as IP('::ffff:192.168.1.1'); RFC 4291
  * Change sort order to more natural:
    IPv4 before IPv6; less-specific prefixes first (/0 before /32)
- Changes from 0.76
  * ip == other and ip != other doesn't fail with an exception anymore if other
    is not a IP object
  * Add IP.get_mac() method: get the 802.3 MAC address from IPv6 RFC 2464
    address.
  * Fix IP('::/0')[0]: return an IPv6 instead of an IPv4 address
- Changes from 0.75
  * IP('::/0').netmask() gives IP('::') instead of IP('0.0.0.0')
- Changes from 0.74
  * Fix tests for Python 3.1 and 3.2
  * ip.__nonzero__() and (ipa in ipb) return a bool instead of 0 or 1
  * IP('0.0.0.0/0') + IP('0.0.0.0/0') raises an error
- Changes from 0.73
  * Support Python 3: setup.py runs 2to3
  * Update the ranges for IPv6 IPs
  * Fix reverseName() and reverseNames() for IPv4 in IPv6 addresses
  * Drop support of Python < 2.5
- Changes from 0.72
  * Include examples and MANIFEST.in in source build (add them to
    MANIFEST.in)
  * Remove __rcsid__ constant from IPy module
- Changes from 0.71
  * Use xrange() instead of range()
  * Use isinstance(x, int) instead of type(x) == types.IntType
  * Prepare support of Python3 (use integer division: x // y)
  * Fix IP(long) constructor: ensure that the address is not too large
  * Constructor raise a TypeError if the type is not int, long,
    str or unicode
  * 223.0.0.0/8 is now public (belongs to APNIC)
- Change Group for standard devel/languages/python
- Remove AUTHOR section
- Remove redundant %%clean section
- Remove --record=INSTALLED_FILES option and replace it with
  %%{python_sitelib} in %%files
- Use download Url as source
* Fri Nov 25 2011 cfarrell@suse.com
- license update: BSD-3-Clause
  SDPX format (http://www.spdx.org/licenses)
* Wed Mar 31 2010 alexandre@exatati.com.br
- Update to 0.70:
  * New "major" version because it may break compatibility
  * Fix __cmp__(): IP('0.0.0.0/0') and IP('0.0.0.0') are not equal
  * Fix IP.net() of the network "::/0": "::" instead of "0.0.0.0". IPy 0.63 should fix this bug, but it wasn't.
  Aditional changes from 0.64:
  * Create MANIFEST.in to fix setup.py bdist_rpm, fix by Robert Nickel
- Spec file cleaned with spec-cleaner;
- Building as noarch for openSUSE >= 11.2.
* Wed Aug 19 2009 jfunk@funktronics.ca
- Update to 0.63
  * Fix formatting of "IPv4 in IPv6" network: IP('::ffff:192.168.10.0/120')
- Version 0.62 (2008-07-15)
  * Fix reverse DNS of IPv6 address: use ".ip6.arpa." suffix instead of
    deprecated ".ip6.int." suffix
- Version 0.61 (2008-06-12)
  * Patch from Aras Vaichas allowing the [-1] operator
    to work with an IP object of size 1.
- Version 0.60 (2008-05-16)
  * strCompressed() formats '::ffff:a.b.c.d' correctly
  * Use strCompressed() instead of strFullsize() to format IP addresses,
    ouput is smarter with IPv6 address
  * Remove check_addr_prefixlen because it generates invalid IP address
* Fri Mar 28 2008 jfunk@funktronics.ca
- Initial release
